
// We are modularizing this manually because the current modularize setting in Emscripten has some issues:
// https://github.com/kripken/emscripten/issues/5820
// In addition, When you use emcc's modularization, it still expects to export a global object called `Module`,
// which is able to be used/called before the WASM is loaded.
// The modularization below exports a promise that loads and resolves to the actual sql.js module.
// That way, this module can't be used before the WASM is finished loading.

// We are going to define a function that a user will call to start loading initializing our Sql.js library
// However, that function might be called multiple times, and on subsequent calls, we don't actually want it to instantiate a new instance of the Module
// Instead, we want to return the previously loaded module

// TODO: Make this not declare a global if used in the browser
var initSqlJsPromise = undefined;

var initSqlJs = function (moduleConfig) {

    if (initSqlJsPromise){
      return initSqlJsPromise;
    }
    // If we're here, we've never called this function before
    initSqlJsPromise = new Promise(function (resolveModule, reject) {

        // We are modularizing this manually because the current modularize setting in Emscripten has some issues:
        // https://github.com/kripken/emscripten/issues/5820

        // The way to affect the loading of emcc compiled modules is to create a variable called `Module` and add
        // properties to it, like `preRun`, `postRun`, etc
        // We are using that to get notified when the WASM has finished loading.
        // Only then will we return our promise

        // If they passed in a moduleConfig object, use that
        // Otherwise, initialize Module to the empty object
        var Module = typeof moduleConfig !== 'undefined' ? moduleConfig : {};

        // EMCC only allows for a single onAbort function (not an array of functions)
        // So if the user defined their own onAbort function, we remember it and call it
        var originalOnAbortFunction = Module['onAbort'];
        Module['onAbort'] = function (errorThatCausedAbort) {
            reject(new Error(errorThatCausedAbort));
            if (originalOnAbortFunction){
              originalOnAbortFunction(errorThatCausedAbort);
            }
        };

        Module['postRun'] = Module['postRun'] || [];
        Module['postRun'].push(function () {
            // When Emscripted calls postRun, this promise resolves with the built Module
            resolveModule(Module);
        });

        // There is a section of code in the emcc-generated code below that looks like this:
        // (Note that this is lowercase `module`)
        // if (typeof module !== 'undefined') {
        //     module['exports'] = Module;
        // }
        // When that runs, it's going to overwrite our own modularization export efforts in shell-post.js!
        // The only way to tell emcc not to emit it is to pass the MODULARIZE=1 or MODULARIZE_INSTANCE=1 flags,
        // but that carries with it additional unnecessary baggage/bugs we don't want either.
        // So, we have three options:
        // 1) We undefine `module`
        // 2) We remember what `module['exports']` was at the beginning of this function and we restore it later
        // 3) We write a script to remove those lines of code as part of the Make process.
        //
        // Since those are the only lines of code that care about module, we will undefine it. It's the most straightforward
        // of the options, and has the side effect of reducing emcc's efforts to modify the module if its output were to change in the future.
        // That's a nice side effect since we're handling the modularization efforts ourselves
        module = undefined;

        // The emcc-generated code and shell-post.js code goes below,
        // meaning that all of it runs inside of this promise. If anything throws an exception, our promise will abort

var Module;Module||(Module=typeof Module !== 'undefined' ? Module : {});null;
Module.onRuntimeInitialized=function(){function a(h,n){this.La=h;this.db=n;this.Ka=1;this.qb=[]}function b(h,n){this.db=n;n=d(h)+1;this.ab=ba(n);if(null===this.ab)throw Error("Unable to allocate memory for the SQL string");r(h,u,this.ab,n);this.mb=this.ab;this.Ya=this.Gb=null}function c(h,{filename:n=!1}={}){!1===n?(this.filename="dbfile_"+(4294967295*Math.random()>>>0),this.Nc=!0,null!=h&&y.tb("/",this.filename,h,!0,!0)):this.filename=h;this.handleError(g(this.filename,e));this.db=B(e,"i32");zb(this.db);
this.gb={};this.Ra={}}var e=C(4),f=Module.cwrap,g=f("sqlite3_open","number",["string","number"]),k=f("sqlite3_close_v2","number",["number"]),l=f("sqlite3_exec","number",["number","string","number","number","number"]),q=f("sqlite3_changes","number",["number"]),m=f("sqlite3_prepare_v2","number",["number","string","number","number","number"]),p=f("sqlite3_sql","string",["number"]),w=f("sqlite3_normalized_sql","string",["number"]),z=f("sqlite3_prepare_v2","number",["number","number","number","number",
"number"]),D=f("sqlite3_bind_text","number",["number","number","number","number","number"]),A=f("sqlite3_bind_blob","number",["number","number","number","number","number"]),U=f("sqlite3_bind_double","number",["number","number","number"]),aa=f("sqlite3_bind_int","number",["number","number","number"]),V=f("sqlite3_bind_parameter_index","number",["number","string"]),Ka=f("sqlite3_step","number",["number"]),E=f("sqlite3_errmsg","string",["number"]),Ab=f("sqlite3_column_count","number",["number"]),Bb=
f("sqlite3_data_count","number",["number"]),Cb=f("sqlite3_column_double","number",["number","number"]),Db=f("sqlite3_column_text","string",["number","number"]),Eb=f("sqlite3_column_blob","number",["number","number"]),Fb=f("sqlite3_column_bytes","number",["number","number"]),Gb=f("sqlite3_column_type","number",["number","number"]),Hb=f("sqlite3_column_name","string",["number","number"]),Ib=f("sqlite3_reset","number",["number"]),Jb=f("sqlite3_clear_bindings","number",["number"]),Kb=f("sqlite3_finalize",
"number",["number"]),Lb=f("sqlite3_create_function_v2","number","number string number number number number number number number".split(" ")),Mb=f("sqlite3_value_type","number",["number"]),Nb=f("sqlite3_value_bytes","number",["number"]),Ob=f("sqlite3_value_text","string",["number"]),Pb=f("sqlite3_value_blob","number",["number"]),Qb=f("sqlite3_value_double","number",["number"]),Rb=f("sqlite3_result_double","",["number","number"]),bb=f("sqlite3_result_null","",["number"]),Sb=f("sqlite3_result_text",
"",["number","string","number","number"]),Tb=f("sqlite3_result_blob","",["number","number","number","number"]),Ub=f("sqlite3_result_int","",["number","number"]),cb=f("sqlite3_result_error","",["number","string","number"]),zb=f("RegisterExtensionFunctions","number",["number"]);a.prototype.bind=function(h){if(!this.La)throw"Statement closed";this.reset();return Array.isArray(h)?this.nc(h):null!=h&&"object"===typeof h?this.oc(h):!0};a.prototype.step=function(){if(!this.La)throw"Statement closed";this.Ka=
1;var h=Ka(this.La);switch(h){case 100:return!0;case 101:return!1;default:throw this.db.handleError(h);}};a.prototype.Hc=function(h){null==h&&(h=this.Ka,this.Ka+=1);return Cb(this.La,h)};a.prototype.Ic=function(h){null==h&&(h=this.Ka,this.Ka+=1);return Db(this.La,h)};a.prototype.getBlob=function(h){null==h&&(h=this.Ka,this.Ka+=1);var n=Fb(this.La,h);h=Eb(this.La,h);for(var t=new Uint8Array(n),v=0;v<n;v+=1)t[v]=H[h+v];return t};a.prototype.get=function(h){null!=h&&this.bind(h)&&this.step();h=[];for(var n=
Bb(this.La),t=0;t<n;t+=1)switch(Gb(this.La,t)){case 1:case 2:h.push(this.Hc(t));break;case 3:h.push(this.Ic(t));break;case 4:h.push(this.getBlob(t));break;default:h.push(null)}return h};a.prototype.getColumnNames=function(){for(var h=[],n=Ab(this.La),t=0;t<n;t+=1)h.push(Hb(this.La,t));return h};a.prototype.getAsObject=function(h){h=this.get(h);for(var n=this.getColumnNames(),t={},v=0;v<n.length;v+=1)t[n[v]]=h[v];return t};a.prototype.getSQL=function(){return p(this.La)};a.prototype.getNormalizedSQL=
function(){return w(this.La)};a.prototype.run=function(h){null!=h&&this.bind(h);this.step();return this.reset()};a.prototype.rc=function(h,n){null==n&&(n=this.Ka,this.Ka+=1);h=ca(h);var t=da(h);this.qb.push(t);this.db.handleError(D(this.La,n,t,h.length-1,0))};a.prototype.mc=function(h,n){null==n&&(n=this.Ka,this.Ka+=1);var t=da(h);this.qb.push(t);this.db.handleError(A(this.La,n,t,h.length,0))};a.prototype.qc=function(h,n){null==n&&(n=this.Ka,this.Ka+=1);this.db.handleError((h===(h|0)?aa:U)(this.La,
n,h))};a.prototype.pc=function(h){null==h&&(h=this.Ka,this.Ka+=1);A(this.La,h,0,0,0)};a.prototype.Nb=function(h,n){null==n&&(n=this.Ka,this.Ka+=1);switch(typeof h){case "string":this.rc(h,n);return;case "number":case "boolean":this.qc(h+0,n);return;case "object":if(null===h){this.pc(n);return}if(null!=h.length){this.mc(h,n);return}}throw"Wrong API use : tried to bind a value of an unknown type ("+h+").";};a.prototype.oc=function(h){var n=this;Object.keys(h).forEach(function(t){var v=V(n.La,t);0!==
v&&n.Nb(h[t],v)});return!0};a.prototype.nc=function(h){for(var n=0;n<h.length;n+=1)this.Nb(h[n],n+1);return!0};a.prototype.reset=function(){return 0===Jb(this.La)&&0===Ib(this.La)};a.prototype.freemem=function(){for(var h;void 0!==(h=this.qb.pop());)ea(h)};a.prototype.free=function(){var h=0===Kb(this.La);delete this.db.gb[this.La];this.La=0;return h};b.prototype.next=function(){if(null===this.ab)return{done:!0};null!==this.Ya&&(this.Ya.free(),this.Ya=null);if(!this.db.db)throw this.vb(),Error("Database closed");
var h=ia(),n=C(4);ja(e);ja(n);try{this.db.handleError(z(this.db.db,this.mb,-1,e,n));this.mb=B(n,"i32");var t=B(e,"i32");if(0===t)return this.vb(),{done:!0};this.Ya=new a(t,this.db);this.db.gb[t]=this.Ya;return{value:this.Ya,done:!1}}catch(v){throw this.Gb=I(this.mb),this.vb(),v;}finally{ka(h)}};b.prototype.vb=function(){ea(this.ab);this.ab=null};b.prototype.getRemainingSQL=function(){return null!==this.Gb?this.Gb:I(this.mb)};"function"===typeof Symbol&&"symbol"===typeof Symbol.iterator&&(b.prototype[Symbol.iterator]=
function(){return this});c.prototype.run=function(h,n){if(!this.db)throw"Database closed";if(n){h=this.prepare(h,n);try{h.step()}finally{h.free()}}else this.handleError(l(this.db,h,0,0,e));return this};c.prototype.exec=function(h,n){if(!this.db)throw"Database closed";var t=ia(),v=null;try{var x=d(h)+1,M=C(x);r(h,H,M,x);var F=M;var fa=C(4);for(h=[];0!==B(F,"i8");){ja(e);ja(fa);this.handleError(z(this.db,F,-1,e,fa));var ha=B(e,"i32");F=B(fa,"i32");if(0!==ha){x=null;v=new a(ha,this);for(null!=n&&v.bind(n);v.step();)null===
x&&(x={columns:v.getColumnNames(),values:[]},h.push(x)),x.values.push(v.get());v.free()}}return h}catch(G){throw v&&v.free(),G;}finally{ka(t)}};c.prototype.each=function(h,n,t,v){"function"===typeof n&&(v=t,t=n,n=void 0);h=this.prepare(h,n);try{for(;h.step();)t(h.getAsObject())}finally{h.free()}if("function"===typeof v)return v()};c.prototype.prepare=function(h,n){ja(e);this.handleError(m(this.db,h,-1,e,0));h=B(e,"i32");if(0===h)throw"Nothing to prepare";var t=new a(h,this);null!=n&&t.bind(n);return this.gb[h]=
t};c.prototype.iterateStatements=function(h){return new b(h,this)};c.prototype["export"]=function(){Object.values(this.gb).forEach(function(n){n.free()});Object.values(this.Ra).forEach(la);this.Ra={};this.handleError(k(this.db));var h=y.readFile(this.filename,{encoding:"binary"});this.handleError(g(this.filename,e));this.db=B(e,"i32");return h};c.prototype.close=function(){null!==this.db&&(Object.values(this.gb).forEach(function(h){h.free()}),Object.values(this.Ra).forEach(la),this.Ra={},this.handleError(k(this.db)),
this.Nc&&y.unlink("/"+this.filename),this.db=null)};c.prototype.handleError=function(h){if(0===h)return null;h=E(this.db);throw Error(h);};c.prototype.getRowsModified=function(){return q(this.db)};c.prototype.create_function=function(h,n){Object.prototype.hasOwnProperty.call(this.Ra,h)&&(la(this.Ra[h]),delete this.Ra[h]);var t=ma(function(v,x,M){for(var F,fa=[],ha=0;ha<x;ha+=1){var G=B(M+4*ha,"i32"),Q=Mb(G);if(1===Q||2===Q)G=Qb(G);else if(3===Q)G=Ob(G);else if(4===Q){Q=G;G=Nb(Q);Q=Pb(Q);for(var db=
new Uint8Array(G),xa=0;xa<G;xa+=1)db[xa]=H[Q+xa];G=db}else G=null;fa.push(G)}try{F=n.apply(null,fa)}catch(Vb){cb(v,Vb,-1);return}switch(typeof F){case "boolean":Ub(v,F?1:0);break;case "number":Rb(v,F);break;case "string":Sb(v,F,-1,-1);break;case "object":null===F?bb(v):null!=F.length?(x=da(F),Tb(v,x,F.length,-1),ea(x)):cb(v,"Wrong API use : tried to return a value of an unknown type ("+F+").",-1);break;default:bb(v)}},"viii");this.Ra[h]=t;this.handleError(Lb(this.db,h,n.length,1,0,t,0,0,0));return this};
Module.Database=c;var oa=new Map;Module.register_for_idb=h=>{let n=ma(function(x,M){x=oa.get(x);return h.lock(x,M)?0:5},"iii"),t=ma(function(x,M){x=oa.get(x);h.unlock(x,M);return 0},"iii"),v=ma(function(x,M){x=I(x);oa.set(M,x)},"vii");Module._register_for_idb(n,t,v)};Module.cleanup_file=h=>{let n=[...oa.entries()].find(t=>t[1]===h);oa.delete(n[0])};Module.reset_filesystem=()=>{y.root=null;y.ec()}};
var na=Object.assign({},Module),pa="./this.program",qa="object"==typeof window,ra="function"==typeof importScripts,sa="object"==typeof process&&"object"==typeof process.versions&&"string"==typeof process.versions.node,J="",ta,ua,va,fs,wa,ya;
if(sa)J=ra?require("path").dirname(J)+"/":__dirname+"/",ya=()=>{wa||(fs=require("fs"),wa=require("path"))},ta=function(a,b){ya();a=wa.normalize(a);return fs.readFileSync(a,b?void 0:"utf8")},va=a=>{a=ta(a,!0);a.buffer||(a=new Uint8Array(a));return a},ua=(a,b,c)=>{ya();a=wa.normalize(a);fs.readFile(a,function(e,f){e?c(e):b(f.buffer)})},1<process.argv.length&&(pa=process.argv[1].replace(/\\/g,"/")),process.argv.slice(2),"undefined"!=typeof module&&(module.exports=Module),Module.inspect=function(){return"[Emscripten Module object]"};
else if(qa||ra)ra?J=self.location.href:"undefined"!=typeof document&&document.currentScript&&(J=document.currentScript.src),J=0!==J.indexOf("blob:")?J.substr(0,J.replace(/[?#].*/,"").lastIndexOf("/")+1):"",ta=a=>{var b=new XMLHttpRequest;b.open("GET",a,!1);b.send(null);return b.responseText},ra&&(va=a=>{var b=new XMLHttpRequest;b.open("GET",a,!1);b.responseType="arraybuffer";b.send(null);return new Uint8Array(b.response)}),ua=(a,b,c)=>{var e=new XMLHttpRequest;e.open("GET",a,!0);e.responseType="arraybuffer";
e.onload=()=>{200==e.status||0==e.status&&e.response?b(e.response):c()};e.onerror=c;e.send(null)};var za=Module.print||console.log.bind(console),K=Module.printErr||console.warn.bind(console);Object.assign(Module,na);na=null;Module.thisProgram&&(pa=Module.thisProgram);function Aa(a){return 128>a?[a]:[a%128|128,a>>7]}var Ba=[],Ca;
function ma(a,b){if(!Ca){Ca=new WeakMap;for(var c=L.length,e=0;e<0+c;e++){var f=Da(e);f&&Ca.set(f,e)}}if(Ca.has(a))return Ca.get(a);if(Ba.length)c=Ba.pop();else{try{L.grow(1)}catch(l){if(!(l instanceof RangeError))throw l;throw"Unable to grow wasm table. Set ALLOW_TABLE_GROWTH.";}c=L.length-1}try{e=c,L.set(e,a),Ea[e]=L.get(e)}catch(l){if(!(l instanceof TypeError))throw l;if("function"==typeof WebAssembly.Function){f={i:"i32",j:"i64",f:"f32",d:"f64",p:"i32"};var g={parameters:[],results:"v"==b[0]?
[]:[f[b[0]]]};for(e=1;e<b.length;++e)g.parameters.push(f[b[e]]);b=new WebAssembly.Function(g,a)}else{f=[1,96];g=b.slice(0,1);b=b.slice(1);var k={i:127,p:127,j:126,f:125,d:124};f=f.concat(Aa(b.length));for(e=0;e<b.length;++e)f.push(k[b[e]]);"v"==g?f.push(0):f=f.concat([1,k[g]]);f=[1].concat(Aa(f.length),f);b=new Uint8Array([0,97,115,109,1,0,0,0].concat(f,[2,7,1,1,101,1,102,0,0,7,5,1,1,102,0,0]));b=new WebAssembly.Module(b);b=(new WebAssembly.Instance(b,{e:{f:a}})).exports.f}e=c;L.set(e,b);Ea[e]=L.get(e)}Ca.set(a,
c);return c}function la(a){Ca.delete(Da(a));Ba.push(a)}var Fa;Module.wasmBinary&&(Fa=Module.wasmBinary);var noExitRuntime=Module.noExitRuntime||!0;"object"!=typeof WebAssembly&&N("no native wasm support detected");var Ga,Ha=!1;
function Ia(a,b,c,e){var f={string:function(m){var p=0;if(null!==m&&void 0!==m&&0!==m){var w=(m.length<<2)+1;p=C(w);r(m,u,p,w)}return p},array:function(m){var p=C(m.length);H.set(m,p);return p}};a=Module["_"+a];var g=[],k=0;if(e)for(var l=0;l<e.length;l++){var q=f[c[l]];q?(0===k&&(k=ia()),g[l]=q(e[l])):g[l]=e[l]}c=a.apply(null,g);return c=function(m){0!==k&&ka(k);return"string"===b?I(m):"boolean"===b?!!m:m}(c)}var Ja=0,La=1;
function da(a){var b=Ja==La?C(a.length):ba(a.length);a.subarray||a.slice||(a=new Uint8Array(a));u.set(a,b);return b}var Ma="undefined"!=typeof TextDecoder?new TextDecoder("utf8"):void 0;
function Na(a,b,c){var e=b+c;for(c=b;a[c]&&!(c>=e);)++c;if(16<c-b&&a.buffer&&Ma)return Ma.decode(a.subarray(b,c));for(e="";b<c;){var f=a[b++];if(f&128){var g=a[b++]&63;if(192==(f&224))e+=String.fromCharCode((f&31)<<6|g);else{var k=a[b++]&63;f=224==(f&240)?(f&15)<<12|g<<6|k:(f&7)<<18|g<<12|k<<6|a[b++]&63;65536>f?e+=String.fromCharCode(f):(f-=65536,e+=String.fromCharCode(55296|f>>10,56320|f&1023))}}else e+=String.fromCharCode(f)}return e}function I(a,b){return a?Na(u,a,b):""}
function r(a,b,c,e){if(!(0<e))return 0;var f=c;e=c+e-1;for(var g=0;g<a.length;++g){var k=a.charCodeAt(g);if(55296<=k&&57343>=k){var l=a.charCodeAt(++g);k=65536+((k&1023)<<10)|l&1023}if(127>=k){if(c>=e)break;b[c++]=k}else{if(2047>=k){if(c+1>=e)break;b[c++]=192|k>>6}else{if(65535>=k){if(c+2>=e)break;b[c++]=224|k>>12}else{if(c+3>=e)break;b[c++]=240|k>>18;b[c++]=128|k>>12&63}b[c++]=128|k>>6&63}b[c++]=128|k&63}}b[c]=0;return c-f}
function d(a){for(var b=0,c=0;c<a.length;++c){var e=a.charCodeAt(c);55296<=e&&57343>=e&&(e=65536+((e&1023)<<10)|a.charCodeAt(++c)&1023);127>=e?++b:b=2047>=e?b+2:65535>=e?b+3:b+4}return b}function Oa(a){var b=d(a)+1,c=ba(b);c&&r(a,H,c,b);return c}var Pa,H,u,Qa,O,P,Ra,Sa;
function Ta(){var a=Ga.buffer;Pa=a;Module.HEAP8=H=new Int8Array(a);Module.HEAP16=Qa=new Int16Array(a);Module.HEAP32=O=new Int32Array(a);Module.HEAPU8=u=new Uint8Array(a);Module.HEAPU16=new Uint16Array(a);Module.HEAPU32=P=new Uint32Array(a);Module.HEAPF32=Ra=new Float32Array(a);Module.HEAPF64=Sa=new Float64Array(a)}var L,Ua=[],Va=[],Wa=[];function Xa(){var a=Module.preRun.shift();Ua.unshift(a)}var Ya=0,Za=null,$a=null;
function ab(){Ya++;Module.monitorRunDependencies&&Module.monitorRunDependencies(Ya)}function eb(){Ya--;Module.monitorRunDependencies&&Module.monitorRunDependencies(Ya);if(0==Ya&&(null!==Za&&(clearInterval(Za),Za=null),$a)){var a=$a;$a=null;a()}}function N(a){if(Module.onAbort)Module.onAbort(a);a="Aborted("+a+")";K(a);Ha=!0;throw new WebAssembly.RuntimeError(a+". Build with -sASSERTIONS for more info.");}function fb(){return R.startsWith("data:application/octet-stream;base64,")}var R;R="sql-wasm.wasm";
if(!fb()){var gb=R;R=Module.locateFile?Module.locateFile(gb,J):J+gb}function hb(){var a=R;try{if(a==R&&Fa)return new Uint8Array(Fa);if(va)return va(a);throw"both async and sync fetching of the wasm failed";}catch(b){N(b)}}
function ib(){if(!Fa&&(qa||ra)){if("function"==typeof fetch&&!R.startsWith("file://"))return fetch(R,{credentials:"same-origin"}).then(function(a){if(!a.ok)throw"failed to load wasm binary file at '"+R+"'";return a.arrayBuffer()}).catch(function(){return hb()});if(ua)return new Promise(function(a,b){ua(R,function(c){a(new Uint8Array(c))},b)})}return Promise.resolve().then(function(){return hb()})}var S,T;
function jb(a){for(;0<a.length;){var b=a.shift();if("function"==typeof b)b(Module);else{var c=b.cd;"number"==typeof c?void 0===b.sb?Da(c)():Da(c)(b.sb):c(void 0===b.sb?null:b.sb)}}}function B(a,b="i8"){b.endsWith("*")&&(b="u32");switch(b){case "i1":return H[a>>0];case "i8":return H[a>>0];case "i16":return Qa[a>>1];case "i32":return O[a>>2];case "i64":return O[a>>2];case "float":return Ra[a>>2];case "double":return Number(Sa[a>>3]);default:N("invalid type for getValue: "+b)}return null}var Ea=[];
function Da(a){var b=Ea[a];b||(a>=Ea.length&&(Ea.length=a+1),Ea[a]=b=L.get(a));return b}
function ja(a){var b="i32";b.endsWith("*")&&(b="u32");switch(b){case "i1":H[a>>0]=0;break;case "i8":H[a>>0]=0;break;case "i16":Qa[a>>1]=0;break;case "i32":O[a>>2]=0;break;case "i64":T=[0,(S=0,1<=+Math.abs(S)?0<S?(Math.min(+Math.floor(S/4294967296),4294967295)|0)>>>0:~~+Math.ceil((S-+(~~S>>>0))/4294967296)>>>0:0)];O[a>>2]=T[0];O[a+4>>2]=T[1];break;case "float":Ra[a>>2]=0;break;case "double":Sa[a>>3]=0;break;default:N("invalid type for setValue: "+b)}}
var kb=(a,b)=>{for(var c=0,e=a.length-1;0<=e;e--){var f=a[e];"."===f?a.splice(e,1):".."===f?(a.splice(e,1),c++):c&&(a.splice(e,1),c--)}if(b)for(;c;c--)a.unshift("..");return a},W=a=>{var b="/"===a.charAt(0),c="/"===a.substr(-1);(a=kb(a.split("/").filter(e=>!!e),!b).join("/"))||b||(a=".");a&&c&&(a+="/");return(b?"/":"")+a},lb=a=>{var b=/^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/.exec(a).slice(1);a=b[0];b=b[1];if(!a&&!b)return".";b&&(b=b.substr(0,b.length-1));return a+b},X=a=>{if("/"===
a)return"/";a=W(a);a=a.replace(/\/$/,"");var b=a.lastIndexOf("/");return-1===b?a:a.substr(b+1)},mb=(a,b)=>W(a+"/"+b);function nb(){if("object"==typeof crypto&&"function"==typeof crypto.getRandomValues){var a=new Uint8Array(1);return function(){crypto.getRandomValues(a);return a[0]}}if(sa)try{var b=require("crypto");return function(){return b.randomBytes(1)[0]}}catch(c){}return function(){N("randomDevice")}}
function ob(){for(var a="",b=!1,c=arguments.length-1;-1<=c&&!b;c--){b=0<=c?arguments[c]:y.cwd();if("string"!=typeof b)throw new TypeError("Arguments to path.resolve must be strings");if(!b)return"";a=b+"/"+a;b="/"===b.charAt(0)}a=kb(a.split("/").filter(e=>!!e),!b).join("/");return(b?"/":"")+a||"."}
var pb=(a,b)=>{function c(k){for(var l=0;l<k.length&&""===k[l];l++);for(var q=k.length-1;0<=q&&""===k[q];q--);return l>q?[]:k.slice(l,q-l+1)}a=ob(a).substr(1);b=ob(b).substr(1);a=c(a.split("/"));b=c(b.split("/"));for(var e=Math.min(a.length,b.length),f=e,g=0;g<e;g++)if(a[g]!==b[g]){f=g;break}e=[];for(g=f;g<a.length;g++)e.push("..");e=e.concat(b.slice(f));return e.join("/")},qb=[];function rb(a,b){qb[a]={input:[],output:[],$a:b};y.Kb(a,sb)}
var sb={open:function(a){var b=qb[a.node.rdev];if(!b)throw new y.ErrnoError(43);a.tty=b;a.seekable=!1},close:function(a){a.tty.$a.flush(a.tty)},flush:function(a){a.tty.$a.flush(a.tty)},read:function(a,b,c,e){if(!a.tty||!a.tty.$a.Yb)throw new y.ErrnoError(60);for(var f=0,g=0;g<e;g++){try{var k=a.tty.$a.Yb(a.tty)}catch(l){throw new y.ErrnoError(29);}if(void 0===k&&0===f)throw new y.ErrnoError(6);if(null===k||void 0===k)break;f++;b[c+g]=k}f&&(a.node.timestamp=Date.now());return f},write:function(a,b,
c,e){if(!a.tty||!a.tty.$a.Hb)throw new y.ErrnoError(60);try{for(var f=0;f<e;f++)a.tty.$a.Hb(a.tty,b[c+f])}catch(g){throw new y.ErrnoError(29);}e&&(a.node.timestamp=Date.now());return f}},tb={Yb:function(a){if(!a.input.length){var b=null;if(sa){var c=Buffer.alloc(256),e=0;try{e=fs.readSync(process.stdin.fd,c,0,256,-1)}catch(f){if(f.toString().includes("EOF"))e=0;else throw f;}0<e?b=c.slice(0,e).toString("utf-8"):b=null}else"undefined"!=typeof window&&"function"==typeof window.prompt?(b=window.prompt("Input: "),
null!==b&&(b+="\n")):"function"==typeof readline&&(b=readline(),null!==b&&(b+="\n"));if(!b)return null;a.input=ca(b,!0)}return a.input.shift()},Hb:function(a,b){null===b||10===b?(za(Na(a.output,0)),a.output=[]):0!=b&&a.output.push(b)},flush:function(a){a.output&&0<a.output.length&&(za(Na(a.output,0)),a.output=[])}},ub={Hb:function(a,b){null===b||10===b?(K(Na(a.output,0)),a.output=[]):0!=b&&a.output.push(b)},flush:function(a){a.output&&0<a.output.length&&(K(Na(a.output,0)),a.output=[])}},Y={Pa:null,
mount:function(){return Y.createNode(null,"/",16895,0)},createNode:function(a,b,c,e){if(y.Jc(c)||y.isFIFO(c))throw new y.ErrnoError(63);Y.Pa||(Y.Pa={dir:{node:{getattr:Y.node_ops.getattr,setattr:Y.node_ops.setattr,lookup:Y.node_ops.lookup,mknod:Y.node_ops.mknod,rename:Y.node_ops.rename,unlink:Y.node_ops.unlink,rmdir:Y.node_ops.rmdir,readdir:Y.node_ops.readdir,symlink:Y.node_ops.symlink},stream:{llseek:Y.stream_ops.llseek}},file:{node:{getattr:Y.node_ops.getattr,setattr:Y.node_ops.setattr},stream:{llseek:Y.stream_ops.llseek,
read:Y.stream_ops.read,write:Y.stream_ops.write,allocate:Y.stream_ops.allocate,mmap:Y.stream_ops.mmap,msync:Y.stream_ops.msync}},link:{node:{getattr:Y.node_ops.getattr,setattr:Y.node_ops.setattr,readlink:Y.node_ops.readlink},stream:{}},Pb:{node:{getattr:Y.node_ops.getattr,setattr:Y.node_ops.setattr},stream:y.vc}});c=y.createNode(a,b,c,e);y.isDir(c.mode)?(c.node_ops=Y.Pa.dir.node,c.stream_ops=Y.Pa.dir.stream,c.Ia={}):y.isFile(c.mode)?(c.node_ops=Y.Pa.file.node,c.stream_ops=Y.Pa.file.stream,c.Ma=0,
c.Ia=null):y.Za(c.mode)?(c.node_ops=Y.Pa.link.node,c.stream_ops=Y.Pa.link.stream):y.jb(c.mode)&&(c.node_ops=Y.Pa.Pb.node,c.stream_ops=Y.Pa.Pb.stream);c.timestamp=Date.now();a&&(a.Ia[b]=c,a.timestamp=c.timestamp);return c},ed:function(a){return a.Ia?a.Ia.subarray?a.Ia.subarray(0,a.Ma):new Uint8Array(a.Ia):new Uint8Array(0)},Ub:function(a,b){var c=a.Ia?a.Ia.length:0;c>=b||(b=Math.max(b,c*(1048576>c?2:1.125)>>>0),0!=c&&(b=Math.max(b,256)),c=a.Ia,a.Ia=new Uint8Array(b),0<a.Ma&&a.Ia.set(c.subarray(0,a.Ma),
0))},Vc:function(a,b){if(a.Ma!=b)if(0==b)a.Ia=null,a.Ma=0;else{var c=a.Ia;a.Ia=new Uint8Array(b);c&&a.Ia.set(c.subarray(0,Math.min(b,a.Ma)));a.Ma=b}},node_ops:{getattr:function(a){var b={};b.dev=y.jb(a.mode)?a.id:1;b.ino=a.id;b.mode=a.mode;b.nlink=1;b.uid=0;b.gid=0;b.rdev=a.rdev;y.isDir(a.mode)?b.size=4096:y.isFile(a.mode)?b.size=a.Ma:y.Za(a.mode)?b.size=a.link.length:b.size=0;b.atime=new Date(a.timestamp);b.mtime=new Date(a.timestamp);b.ctime=new Date(a.timestamp);b.sc=4096;b.blocks=Math.ceil(b.size/
b.sc);return b},setattr:function(a,b){void 0!==b.mode&&(a.mode=b.mode);void 0!==b.timestamp&&(a.timestamp=b.timestamp);void 0!==b.size&&Y.Vc(a,b.size)},lookup:function(){throw y.xb[44];},mknod:function(a,b,c,e){return Y.createNode(a,b,c,e)},rename:function(a,b,c){if(y.isDir(a.mode)){try{var e=y.lookupNode(b,c)}catch(g){}if(e)for(var f in e.Ia)throw new y.ErrnoError(55);}delete a.parent.Ia[a.name];a.parent.timestamp=Date.now();a.name=c;b.Ia[c]=a;b.timestamp=a.parent.timestamp;a.parent=b},unlink:function(a,
b){delete a.Ia[b];a.timestamp=Date.now()},rmdir:function(a,b){var c=y.lookupNode(a,b),e;for(e in c.Ia)throw new y.ErrnoError(55);delete a.Ia[b];a.timestamp=Date.now()},readdir:function(a){var b=[".",".."],c;for(c in a.Ia)a.Ia.hasOwnProperty(c)&&b.push(c);return b},symlink:function(a,b,c){a=Y.createNode(a,b,41471,0);a.link=c;return a},readlink:function(a){if(!y.Za(a.mode))throw new y.ErrnoError(28);return a.link}},stream_ops:{read:function(a,b,c,e,f){var g=a.node.Ia;if(f>=a.node.Ma)return 0;a=Math.min(a.node.Ma-
f,e);if(8<a&&g.subarray)b.set(g.subarray(f,f+a),c);else for(e=0;e<a;e++)b[c+e]=g[f+e];return a},write:function(a,b,c,e,f,g){b.buffer===H.buffer&&(g=!1);if(!e)return 0;a=a.node;a.timestamp=Date.now();if(b.subarray&&(!a.Ia||a.Ia.subarray)){if(g)return a.Ia=b.subarray(c,c+e),a.Ma=e;if(0===a.Ma&&0===f)return a.Ia=b.slice(c,c+e),a.Ma=e;if(f+e<=a.Ma)return a.Ia.set(b.subarray(c,c+e),f),e}Y.Ub(a,f+e);if(a.Ia.subarray&&b.subarray)a.Ia.set(b.subarray(c,c+e),f);else for(g=0;g<e;g++)a.Ia[f+g]=b[c+g];a.Ma=Math.max(a.Ma,
f+e);return e},llseek:function(a,b,c){1===c?b+=a.position:2===c&&y.isFile(a.node.mode)&&(b+=a.node.Ma);if(0>b)throw new y.ErrnoError(28);return b},allocate:function(a,b,c){Y.Ub(a.node,b+c);a.node.Ma=Math.max(a.node.Ma,b+c)},mmap:function(a,b,c,e,f){if(!y.isFile(a.node.mode))throw new y.ErrnoError(43);a=a.node.Ia;if(f&2||a.buffer!==Pa){if(0<c||c+b<a.length)a.subarray?a=a.subarray(c,c+b):a=Array.prototype.slice.call(a,c,c+b);c=!0;b=65536*Math.ceil(b/65536);(f=vb(65536,b))?(u.fill(0,f,f+b),b=f):b=0;
if(!b)throw new y.ErrnoError(48);H.set(a,b)}else c=!1,b=a.byteOffset;return{Uc:b,lc:c}},msync:function(a,b,c,e,f){if(!y.isFile(a.node.mode))throw new y.ErrnoError(43);if(f&2)return 0;Y.stream_ops.write(a,b,0,e,c,!1);return 0}}};function wb(a,b,c){var e="al "+a;ua(a,function(f){f||N('Loading data file "'+a+'" failed (no arrayBuffer).');b(new Uint8Array(f));e&&eb()},function(){if(c)c();else throw'Loading data file "'+a+'" failed.';});e&&ab()}
var y={root:null,fb:[],Sb:{},streams:[],Pc:1,Oa:null,Rb:"/",Bb:!1,bc:!0,ErrnoError:null,xb:{},Dc:null,ob:0,lookupPath:(a,b={})=>{a=ob(y.cwd(),a);if(!a)return{path:"",node:null};b=Object.assign({wb:!0,Jb:0},b);if(8<b.Jb)throw new y.ErrnoError(32);a=kb(a.split("/").filter(k=>!!k),!1);for(var c=y.root,e="/",f=0;f<a.length;f++){var g=f===a.length-1;if(g&&b.parent)break;c=y.lookupNode(c,a[f]);e=W(e+"/"+a[f]);y.Va(c)&&(!g||g&&b.wb)&&(c=c.eb.root);if(!g||b.Na)for(g=0;y.Za(c.mode);)if(c=y.readlink(e),e=ob(lb(e),
c),c=y.lookupPath(e,{Jb:b.Jb+1}).node,40<g++)throw new y.ErrnoError(32);}return{path:e,node:c}},Sa:a=>{for(var b;;){if(y.isRoot(a))return a=a.mount.dc,b?"/"!==a[a.length-1]?a+"/"+b:a+b:a;b=b?a.name+"/"+b:a.name;a=a.parent}},Ab:(a,b)=>{for(var c=0,e=0;e<b.length;e++)c=(c<<5)-c+b.charCodeAt(e)|0;return(a+c>>>0)%y.Oa.length},$b:a=>{var b=y.Ab(a.parent.id,a.name);a.Xa=y.Oa[b];y.Oa[b]=a},ac:a=>{var b=y.Ab(a.parent.id,a.name);if(y.Oa[b]===a)y.Oa[b]=a.Xa;else for(b=y.Oa[b];b;){if(b.Xa===a){b.Xa=a.Xa;break}b=
b.Xa}},lookupNode:(a,b)=>{var c=y.Lc(a);if(c)throw new y.ErrnoError(c,a);for(c=y.Oa[y.Ab(a.id,b)];c;c=c.Xa){var e=c.name;if(c.parent.id===a.id&&e===b)return c}return y.lookup(a,b)},createNode:(a,b,c,e)=>{a=new y.FSNode(a,b,c,e);y.$b(a);return a},ub:a=>{y.ac(a)},isRoot:a=>a===a.parent,Va:a=>!!a.eb,isFile:a=>32768===(a&61440),isDir:a=>16384===(a&61440),Za:a=>40960===(a&61440),jb:a=>8192===(a&61440),Jc:a=>24576===(a&61440),isFIFO:a=>4096===(a&61440),isSocket:a=>49152===(a&49152),Ec:{r:0,"r+":2,w:577,
"w+":578,a:1089,"a+":1090},Oc:a=>{var b=y.Ec[a];if("undefined"==typeof b)throw Error("Unknown file open mode: "+a);return b},Vb:a=>{var b=["r","w","rw"][a&3];a&512&&(b+="w");return b},Ua:(a,b)=>{if(y.bc)return 0;if(!b.includes("r")||a.mode&292){if(b.includes("w")&&!(a.mode&146)||b.includes("x")&&!(a.mode&73))return 2}else return 2;return 0},Lc:a=>{var b=y.Ua(a,"x");return b?b:a.node_ops.lookup?0:2},Fb:(a,b)=>{try{return y.lookupNode(a,b),20}catch(c){}return y.Ua(a,"wx")},kb:(a,b,c)=>{try{var e=y.lookupNode(a,
b)}catch(f){return f.Ja}if(a=y.Ua(a,"wx"))return a;if(c){if(!y.isDir(e.mode))return 54;if(y.isRoot(e)||y.Sa(e)===y.cwd())return 10}else if(y.isDir(e.mode))return 31;return 0},Mc:(a,b)=>a?y.Za(a.mode)?32:y.isDir(a.mode)&&("r"!==y.Vb(b)||b&512)?31:y.Ua(a,y.Vb(b)):44,ic:4096,Qc:(a=0,b=y.ic)=>{for(;a<=b;a++)if(!y.streams[a])return a;throw new y.ErrnoError(33);},Ta:a=>y.streams[a],Qb:(a,b,c)=>{y.pb||(y.pb=function(){this.nb={}},y.pb.prototype={object:{get:function(){return this.node},set:function(e){this.node=
e}},flags:{get:function(){return this.nb.flags},set:function(e){this.nb.flags=e}},position:{get dd(){return this.nb.position},set:function(e){this.nb.position=e}}});a=Object.assign(new y.pb,a);b=y.Qc(b,c);a.fd=b;return y.streams[b]=a},wc:a=>{y.streams[a]=null},vc:{open:a=>{a.stream_ops=y.Gc(a.node.rdev).stream_ops;a.stream_ops.open&&a.stream_ops.open(a)},llseek:()=>{throw new y.ErrnoError(70);}},Eb:a=>a>>8,jd:a=>a&255,Wa:(a,b)=>a<<8|b,Kb:(a,b)=>{y.Sb[a]={stream_ops:b}},Gc:a=>y.Sb[a],Xb:a=>{var b=
[];for(a=[a];a.length;){var c=a.pop();b.push(c);a.push.apply(a,c.fb)}return b},fc:(a,b)=>{function c(k){y.ob--;return b(k)}function e(k){if(k){if(!e.Cc)return e.Cc=!0,c(k)}else++g>=f.length&&c(null)}"function"==typeof a&&(b=a,a=!1);y.ob++;1<y.ob&&K("warning: "+y.ob+" FS.syncfs operations in flight at once, probably just doing extra work");var f=y.Xb(y.root.mount),g=0;f.forEach(k=>{if(!k.type.fc)return e(null);k.type.fc(k,a,e)})},mount:(a,b,c)=>{var e="/"===c,f=!c;if(e&&y.root)throw new y.ErrnoError(10);
if(!e&&!f){var g=y.lookupPath(c,{wb:!1});c=g.path;g=g.node;if(y.Va(g))throw new y.ErrnoError(10);if(!y.isDir(g.mode))throw new y.ErrnoError(54);}b={type:a,md:b,dc:c,fb:[]};a=a.mount(b);a.mount=b;b.root=a;e?y.root=a:g&&(g.eb=b,g.mount&&g.mount.fb.push(b));return a},pd:a=>{a=y.lookupPath(a,{wb:!1});if(!y.Va(a.node))throw new y.ErrnoError(28);a=a.node;var b=a.eb,c=y.Xb(b);Object.keys(y.Oa).forEach(e=>{for(e=y.Oa[e];e;){var f=e.Xa;c.includes(e.mount)&&y.ub(e);e=f}});a.eb=null;a.mount.fb.splice(a.mount.fb.indexOf(b),
1)},lookup:(a,b)=>a.node_ops.lookup(a,b),mknod:(a,b,c)=>{var e=y.lookupPath(a,{parent:!0}).node;a=X(a);if(!a||"."===a||".."===a)throw new y.ErrnoError(28);var f=y.Fb(e,a);if(f)throw new y.ErrnoError(f);if(!e.node_ops.mknod)throw new y.ErrnoError(63);return e.node_ops.mknod(e,a,b,c)},create:(a,b)=>y.mknod(a,(void 0!==b?b:438)&4095|32768,0),mkdir:(a,b)=>y.mknod(a,(void 0!==b?b:511)&1023|16384,0),kd:(a,b)=>{a=a.split("/");for(var c="",e=0;e<a.length;++e)if(a[e]){c+="/"+a[e];try{y.mkdir(c,b)}catch(f){if(20!=
f.Ja)throw f;}}},lb:(a,b,c)=>{"undefined"==typeof c&&(c=b,b=438);return y.mknod(a,b|8192,c)},symlink:(a,b)=>{if(!ob(a))throw new y.ErrnoError(44);var c=y.lookupPath(b,{parent:!0}).node;if(!c)throw new y.ErrnoError(44);b=X(b);var e=y.Fb(c,b);if(e)throw new y.ErrnoError(e);if(!c.node_ops.symlink)throw new y.ErrnoError(63);return c.node_ops.symlink(c,b,a)},rename:(a,b)=>{var c=lb(a),e=lb(b),f=X(a),g=X(b);var k=y.lookupPath(a,{parent:!0});var l=k.node;k=y.lookupPath(b,{parent:!0});k=k.node;if(!l||!k)throw new y.ErrnoError(44);
if(l.mount!==k.mount)throw new y.ErrnoError(75);var q=y.lookupNode(l,f);a=pb(a,e);if("."!==a.charAt(0))throw new y.ErrnoError(28);a=pb(b,c);if("."!==a.charAt(0))throw new y.ErrnoError(55);try{var m=y.lookupNode(k,g)}catch(p){}if(q!==m){b=y.isDir(q.mode);if(f=y.kb(l,f,b))throw new y.ErrnoError(f);if(f=m?y.kb(k,g,b):y.Fb(k,g))throw new y.ErrnoError(f);if(!l.node_ops.rename)throw new y.ErrnoError(63);if(y.Va(q)||m&&y.Va(m))throw new y.ErrnoError(10);if(k!==l&&(f=y.Ua(l,"w")))throw new y.ErrnoError(f);
y.ac(q);try{l.node_ops.rename(q,k,g)}catch(p){throw p;}finally{y.$b(q)}}},rmdir:a=>{var b=y.lookupPath(a,{parent:!0}).node;a=X(a);var c=y.lookupNode(b,a),e=y.kb(b,a,!0);if(e)throw new y.ErrnoError(e);if(!b.node_ops.rmdir)throw new y.ErrnoError(63);if(y.Va(c))throw new y.ErrnoError(10);b.node_ops.rmdir(b,a);y.ub(c)},readdir:a=>{a=y.lookupPath(a,{Na:!0}).node;if(!a.node_ops.readdir)throw new y.ErrnoError(54);return a.node_ops.readdir(a)},unlink:a=>{var b=y.lookupPath(a,{parent:!0}).node;if(!b)throw new y.ErrnoError(44);
a=X(a);var c=y.lookupNode(b,a),e=y.kb(b,a,!1);if(e)throw new y.ErrnoError(e);if(!b.node_ops.unlink)throw new y.ErrnoError(63);if(y.Va(c))throw new y.ErrnoError(10);b.node_ops.unlink(b,a);y.ub(c)},readlink:a=>{a=y.lookupPath(a).node;if(!a)throw new y.ErrnoError(44);if(!a.node_ops.readlink)throw new y.ErrnoError(28);return ob(y.Sa(a.parent),a.node_ops.readlink(a))},stat:(a,b)=>{a=y.lookupPath(a,{Na:!b}).node;if(!a)throw new y.ErrnoError(44);if(!a.node_ops.getattr)throw new y.ErrnoError(63);return a.node_ops.getattr(a)},
lstat:a=>y.stat(a,!0),chmod:(a,b,c)=>{a="string"==typeof a?y.lookupPath(a,{Na:!c}).node:a;if(!a.node_ops.setattr)throw new y.ErrnoError(63);a.node_ops.setattr(a,{mode:b&4095|a.mode&-4096,timestamp:Date.now()})},lchmod:(a,b)=>{y.chmod(a,b,!0)},fchmod:(a,b)=>{a=y.Ta(a);if(!a)throw new y.ErrnoError(8);y.chmod(a.node,b)},chown:(a,b,c,e)=>{a="string"==typeof a?y.lookupPath(a,{Na:!e}).node:a;if(!a.node_ops.setattr)throw new y.ErrnoError(63);a.node_ops.setattr(a,{timestamp:Date.now()})},lchown:(a,b,c)=>
{y.chown(a,b,c,!0)},fchown:(a,b,c)=>{a=y.Ta(a);if(!a)throw new y.ErrnoError(8);y.chown(a.node,b,c)},truncate:(a,b)=>{if(0>b)throw new y.ErrnoError(28);a="string"==typeof a?y.lookupPath(a,{Na:!0}).node:a;if(!a.node_ops.setattr)throw new y.ErrnoError(63);if(y.isDir(a.mode))throw new y.ErrnoError(31);if(!y.isFile(a.mode))throw new y.ErrnoError(28);var c=y.Ua(a,"w");if(c)throw new y.ErrnoError(c);a.node_ops.setattr(a,{size:b,timestamp:Date.now()})},Fc:(a,b)=>{a=y.Ta(a);if(!a)throw new y.ErrnoError(8);
if(0===(a.flags&2097155))throw new y.ErrnoError(28);y.truncate(a.node,b)},Yc:(a,b,c)=>{a=y.lookupPath(a,{Na:!0}).node;a.node_ops.setattr(a,{timestamp:Math.max(b,c)})},open:(a,b,c)=>{if(""===a)throw new y.ErrnoError(44);b="string"==typeof b?y.Oc(b):b;c=b&64?("undefined"==typeof c?438:c)&4095|32768:0;if("object"==typeof a)var e=a;else{a=W(a);try{e=y.lookupPath(a,{Na:!(b&131072)}).node}catch(g){}}var f=!1;if(b&64)if(e){if(b&128)throw new y.ErrnoError(20);}else e=y.mknod(a,c,0),f=!0;if(!e)throw new y.ErrnoError(44);
y.jb(e.mode)&&(b&=-513);if(b&65536&&!y.isDir(e.mode))throw new y.ErrnoError(54);if(!f&&(c=y.Mc(e,b)))throw new y.ErrnoError(c);b&512&&!f&&y.truncate(e,0);b&=-131713;e=y.Qb({node:e,path:y.Sa(e),flags:b,seekable:!0,position:0,stream_ops:e.stream_ops,Xc:[],error:!1});e.stream_ops.open&&e.stream_ops.open(e);!Module.logReadFiles||b&1||(y.Ib||(y.Ib={}),a in y.Ib||(y.Ib[a]=1));return e},close:a=>{if(y.cb(a))throw new y.ErrnoError(8);a.zb&&(a.zb=null);try{a.stream_ops.close&&a.stream_ops.close(a)}catch(b){throw b;
}finally{y.wc(a.fd)}a.fd=null},cb:a=>null===a.fd,llseek:(a,b,c)=>{if(y.cb(a))throw new y.ErrnoError(8);if(!a.seekable||!a.stream_ops.llseek)throw new y.ErrnoError(70);if(0!=c&&1!=c&&2!=c)throw new y.ErrnoError(28);a.position=a.stream_ops.llseek(a,b,c);a.Xc=[];return a.position},read:(a,b,c,e,f)=>{if(0>e||0>f)throw new y.ErrnoError(28);if(y.cb(a))throw new y.ErrnoError(8);if(1===(a.flags&2097155))throw new y.ErrnoError(8);if(y.isDir(a.node.mode))throw new y.ErrnoError(31);if(!a.stream_ops.read)throw new y.ErrnoError(28);
var g="undefined"!=typeof f;if(!g)f=a.position;else if(!a.seekable)throw new y.ErrnoError(70);b=a.stream_ops.read(a,b,c,e,f);g||(a.position+=b);return b},write:(a,b,c,e,f,g)=>{if(0>e||0>f)throw new y.ErrnoError(28);if(y.cb(a))throw new y.ErrnoError(8);if(0===(a.flags&2097155))throw new y.ErrnoError(8);if(y.isDir(a.node.mode))throw new y.ErrnoError(31);if(!a.stream_ops.write)throw new y.ErrnoError(28);a.seekable&&a.flags&1024&&y.llseek(a,0,2);var k="undefined"!=typeof f;if(!k)f=a.position;else if(!a.seekable)throw new y.ErrnoError(70);
b=a.stream_ops.write(a,b,c,e,f,g);k||(a.position+=b);return b},allocate:(a,b,c)=>{if(y.cb(a))throw new y.ErrnoError(8);if(0>b||0>=c)throw new y.ErrnoError(28);if(0===(a.flags&2097155))throw new y.ErrnoError(8);if(!y.isFile(a.node.mode)&&!y.isDir(a.node.mode))throw new y.ErrnoError(43);if(!a.stream_ops.allocate)throw new y.ErrnoError(138);a.stream_ops.allocate(a,b,c)},mmap:(a,b,c,e,f)=>{if(0!==(e&2)&&0===(f&2)&&2!==(a.flags&2097155))throw new y.ErrnoError(2);if(1===(a.flags&2097155))throw new y.ErrnoError(2);
if(!a.stream_ops.mmap)throw new y.ErrnoError(43);return a.stream_ops.mmap(a,b,c,e,f)},msync:(a,b,c,e,f)=>a&&a.stream_ops.msync?a.stream_ops.msync(a,b,c,e,f):0,ld:()=>0,cc:(a,b,c)=>{if(!a.stream_ops.cc)throw new y.ErrnoError(59);return a.stream_ops.cc(a,b,c)},readFile:(a,b={})=>{b.flags=b.flags||0;b.encoding=b.encoding||"binary";if("utf8"!==b.encoding&&"binary"!==b.encoding)throw Error('Invalid encoding type "'+b.encoding+'"');var c,e=y.open(a,b.flags);a=y.stat(a).size;var f=new Uint8Array(a);y.read(e,
f,0,a,0);"utf8"===b.encoding?c=Na(f,0):"binary"===b.encoding&&(c=f);y.close(e);return c},writeFile:(a,b,c={})=>{c.flags=c.flags||577;a=y.open(a,c.flags,c.mode);if("string"==typeof b){var e=new Uint8Array(d(b)+1);b=r(b,e,0,e.length);y.write(a,e,0,b,void 0,c.uc)}else if(ArrayBuffer.isView(b))y.write(a,b,0,b.byteLength,void 0,c.uc);else throw Error("Unsupported data type");y.close(a)},cwd:()=>y.Rb,chdir:a=>{a=y.lookupPath(a,{Na:!0});if(null===a.node)throw new y.ErrnoError(44);if(!y.isDir(a.node.mode))throw new y.ErrnoError(54);
var b=y.Ua(a.node,"x");if(b)throw new y.ErrnoError(b);y.Rb=a.path},yc:()=>{y.mkdir("/tmp");y.mkdir("/home");y.mkdir("/home/web_user")},xc:()=>{y.mkdir("/dev");y.Kb(y.Wa(1,3),{read:()=>0,write:(b,c,e,f)=>f});y.lb("/dev/null",y.Wa(1,3));rb(y.Wa(5,0),tb);rb(y.Wa(6,0),ub);y.lb("/dev/tty",y.Wa(5,0));y.lb("/dev/tty1",y.Wa(6,0));var a=nb();y.Qa("/dev","random",a);y.Qa("/dev","urandom",a);y.mkdir("/dev/shm");y.mkdir("/dev/shm/tmp")},Ac:()=>{y.mkdir("/proc");var a=y.mkdir("/proc/self");y.mkdir("/proc/self/fd");
y.mount({mount:()=>{var b=y.createNode(a,"fd",16895,73);b.node_ops={lookup:(c,e)=>{var f=y.Ta(+e);if(!f)throw new y.ErrnoError(8);c={parent:null,mount:{dc:"fake"},node_ops:{readlink:()=>f.path}};return c.parent=c}};return b}},{},"/proc/self/fd")},Bc:()=>{Module.stdin?y.Qa("/dev","stdin",Module.stdin):y.symlink("/dev/tty","/dev/stdin");Module.stdout?y.Qa("/dev","stdout",null,Module.stdout):y.symlink("/dev/tty","/dev/stdout");Module.stderr?y.Qa("/dev","stderr",null,Module.stderr):y.symlink("/dev/tty1",
"/dev/stderr");y.open("/dev/stdin",0);y.open("/dev/stdout",1);y.open("/dev/stderr",1)},Tb:()=>{y.ErrnoError||(y.ErrnoError=function(a,b){this.node=b;this.Wc=function(c){this.Ja=c};this.Wc(a);this.message="FS error"},y.ErrnoError.prototype=Error(),y.ErrnoError.prototype.constructor=y.ErrnoError,[44].forEach(a=>{y.xb[a]=new y.ErrnoError(a);y.xb[a].stack="<generic error, no stack>"}))},ec:()=>{y.Tb();y.Oa=Array(4096);y.mount(Y,{},"/");y.yc();y.xc();y.Ac();y.Dc={MEMFS:Y}},ib:(a,b,c)=>{y.ib.Bb=!0;y.Tb();
Module.stdin=a||Module.stdin;Module.stdout=b||Module.stdout;Module.stderr=c||Module.stderr;y.Bc()},nd:()=>{y.ib.Bb=!1;for(var a=0;a<y.streams.length;a++){var b=y.streams[a];b&&y.close(b)}},yb:(a,b)=>{var c=0;a&&(c|=365);b&&(c|=146);return c},bd:(a,b)=>{a=y.rb(a,b);return a.exists?a.object:null},rb:(a,b)=>{try{var c=y.lookupPath(a,{Na:!b});a=c.path}catch(f){}var e={isRoot:!1,exists:!1,error:0,name:null,path:null,object:null,Rc:!1,Tc:null,Sc:null};try{c=y.lookupPath(a,{parent:!0}),e.Rc=!0,e.Tc=c.path,
e.Sc=c.node,e.name=X(a),c=y.lookupPath(a,{Na:!b}),e.exists=!0,e.path=c.path,e.object=c.node,e.name=c.node.name,e.isRoot="/"===c.path}catch(f){e.error=f.Ja}return e},$c:(a,b)=>{a="string"==typeof a?a:y.Sa(a);for(b=b.split("/").reverse();b.length;){var c=b.pop();if(c){var e=W(a+"/"+c);try{y.mkdir(e)}catch(f){}a=e}}return e},zc:(a,b,c,e,f)=>{a="string"==typeof a?a:y.Sa(a);b=W(a+"/"+b);return y.create(b,y.yb(e,f))},tb:(a,b,c,e,f,g)=>{var k=b;a&&(a="string"==typeof a?a:y.Sa(a),k=b?W(a+"/"+b):a);a=y.yb(e,
f);k=y.create(k,a);if(c){if("string"==typeof c){b=Array(c.length);e=0;for(f=c.length;e<f;++e)b[e]=c.charCodeAt(e);c=b}y.chmod(k,a|146);b=y.open(k,577);y.write(b,c,0,c.length,0,g);y.close(b);y.chmod(k,a)}return k},Qa:(a,b,c,e)=>{a=mb("string"==typeof a?a:y.Sa(a),b);b=y.yb(!!c,!!e);y.Qa.Eb||(y.Qa.Eb=64);var f=y.Wa(y.Qa.Eb++,0);y.Kb(f,{open:g=>{g.seekable=!1},close:()=>{e&&e.buffer&&e.buffer.length&&e(10)},read:(g,k,l,q)=>{for(var m=0,p=0;p<q;p++){try{var w=c()}catch(z){throw new y.ErrnoError(29);}if(void 0===
w&&0===m)throw new y.ErrnoError(6);if(null===w||void 0===w)break;m++;k[l+p]=w}m&&(g.node.timestamp=Date.now());return m},write:(g,k,l,q)=>{for(var m=0;m<q;m++)try{e(k[l+m])}catch(p){throw new y.ErrnoError(29);}q&&(g.node.timestamp=Date.now());return m}});return y.lb(a,b,f)},Wb:a=>{if(a.Cb||a.Kc||a.link||a.Ia)return!0;if("undefined"!=typeof XMLHttpRequest)throw Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
if(ta)try{a.Ia=ca(ta(a.url),!0),a.Ma=a.Ia.length}catch(b){throw new y.ErrnoError(29);}else throw Error("Cannot load without read() or XMLHttpRequest.");},Zc:(a,b,c,e,f)=>{function g(){this.Db=!1;this.hb=[]}g.prototype.get=function(m){if(!(m>this.length-1||0>m)){var p=m%this.chunkSize;return this.Zb(m/this.chunkSize|0)[p]}};g.prototype.hc=function(m){this.Zb=m};g.prototype.Ob=function(){var m=new XMLHttpRequest;m.open("HEAD",c,!1);m.send(null);if(!(200<=m.status&&300>m.status||304===m.status))throw Error("Couldn't load "+
c+". Status: "+m.status);var p=Number(m.getResponseHeader("Content-length")),w,z=(w=m.getResponseHeader("Accept-Ranges"))&&"bytes"===w;m=(w=m.getResponseHeader("Content-Encoding"))&&"gzip"===w;var D=1048576;z||(D=p);var A=this;A.hc(U=>{var aa=U*D,V=(U+1)*D-1;V=Math.min(V,p-1);if("undefined"==typeof A.hb[U]){var Ka=A.hb;if(aa>V)throw Error("invalid range ("+aa+", "+V+") or no bytes requested!");if(V>p-1)throw Error("only "+p+" bytes available! programmer error!");var E=new XMLHttpRequest;E.open("GET",
c,!1);p!==D&&E.setRequestHeader("Range","bytes="+aa+"-"+V);E.responseType="arraybuffer";E.overrideMimeType&&E.overrideMimeType("text/plain; charset=x-user-defined");E.send(null);if(!(200<=E.status&&300>E.status||304===E.status))throw Error("Couldn't load "+c+". Status: "+E.status);aa=void 0!==E.response?new Uint8Array(E.response||[]):ca(E.responseText||"",!0);Ka[U]=aa}if("undefined"==typeof A.hb[U])throw Error("doXHR failed!");return A.hb[U]});if(m||!p)D=p=1,D=p=this.Zb(0).length,za("LazyFiles on gzip forces download of the whole file when length is accessed");
this.kc=p;this.jc=D;this.Db=!0};if("undefined"!=typeof XMLHttpRequest){if(!ra)throw"Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc";var k=new g;Object.defineProperties(k,{length:{get:function(){this.Db||this.Ob();return this.kc}},chunkSize:{get:function(){this.Db||this.Ob();return this.jc}}});k={Cb:!1,Ia:k}}else k={Cb:!1,url:c};var l=y.zc(a,b,k,e,f);k.Ia?l.Ia=k.Ia:k.url&&(l.Ia=null,l.url=k.url);Object.defineProperties(l,{Ma:{get:function(){return this.Ia.length}}});
var q={};Object.keys(l.stream_ops).forEach(m=>{var p=l.stream_ops[m];q[m]=function(){y.Wb(l);return p.apply(null,arguments)}});q.read=(m,p,w,z,D)=>{y.Wb(l);m=m.node.Ia;if(D>=m.length)return 0;z=Math.min(m.length-D,z);if(m.slice)for(var A=0;A<z;A++)p[w+A]=m[D+A];else for(A=0;A<z;A++)p[w+A]=m.get(D+A);return z};l.stream_ops=q;return l},ad:(a,b,c,e,f,g,k,l,q,m)=>{function p(z){function D(A){m&&m();l||y.tb(a,b,A,e,f,q);g&&g();eb()}xb.gd(z,w,D,()=>{k&&k();eb()})||D(z)}var w=b?ob(W(a+"/"+b)):a;ab();"string"==
typeof c?wb(c,z=>p(z),k):p(c)},indexedDB:()=>window.indexedDB||window.mozIndexedDB||window.webkitIndexedDB||window.msIndexedDB,Lb:()=>"EM_FS_"+window.location.pathname,Mb:20,bb:"FILE_DATA",od:(a,b,c)=>{b=b||(()=>{});c=c||(()=>{});var e=y.indexedDB();try{var f=e.open(y.Lb(),y.Mb)}catch(g){return c(g)}f.onupgradeneeded=()=>{za("creating db");f.result.createObjectStore(y.bb)};f.onsuccess=()=>{var g=f.result.transaction([y.bb],"readwrite"),k=g.objectStore(y.bb),l=0,q=0,m=a.length;a.forEach(p=>{p=k.put(y.rb(p).object.Ia,
p);p.onsuccess=()=>{l++;l+q==m&&(0==q?b():c())};p.onerror=()=>{q++;l+q==m&&(0==q?b():c())}});g.onerror=c};f.onerror=c},hd:(a,b,c)=>{b=b||(()=>{});c=c||(()=>{});var e=y.indexedDB();try{var f=e.open(y.Lb(),y.Mb)}catch(g){return c(g)}f.onupgradeneeded=c;f.onsuccess=()=>{var g=f.result;try{var k=g.transaction([y.bb],"readonly")}catch(w){c(w);return}var l=k.objectStore(y.bb),q=0,m=0,p=a.length;a.forEach(w=>{var z=l.get(w);z.onsuccess=()=>{y.rb(w).exists&&y.unlink(w);y.tb(lb(w),X(w),z.result,!0,!0,!0);
q++;q+m==p&&(0==m?b():c())};z.onerror=()=>{m++;q+m==p&&(0==m?b():c())}});k.onerror=c};f.onerror=c}};function yb(a,b,c){if("/"===b.charAt(0))return b;if(-100===a)a=y.cwd();else{a=y.Ta(a);if(!a)throw new y.ErrnoError(8);a=a.path}if(0==b.length){if(!c)throw new y.ErrnoError(44);return a}return W(a+"/"+b)}
function Wb(a,b,c){try{var e=a(b)}catch(f){if(f&&f.node&&W(b)!==W(y.Sa(f.node)))return-54;throw f;}O[c>>2]=e.dev;O[c+4>>2]=0;O[c+8>>2]=e.ino;O[c+12>>2]=e.mode;O[c+16>>2]=e.nlink;O[c+20>>2]=e.uid;O[c+24>>2]=e.gid;O[c+28>>2]=e.rdev;O[c+32>>2]=0;T=[e.size>>>0,(S=e.size,1<=+Math.abs(S)?0<S?(Math.min(+Math.floor(S/4294967296),4294967295)|0)>>>0:~~+Math.ceil((S-+(~~S>>>0))/4294967296)>>>0:0)];O[c+40>>2]=T[0];O[c+44>>2]=T[1];O[c+48>>2]=4096;O[c+52>>2]=e.blocks;O[c+56>>2]=e.atime.getTime()/1E3|0;O[c+60>>
2]=0;O[c+64>>2]=e.mtime.getTime()/1E3|0;O[c+68>>2]=0;O[c+72>>2]=e.ctime.getTime()/1E3|0;O[c+76>>2]=0;T=[e.ino>>>0,(S=e.ino,1<=+Math.abs(S)?0<S?(Math.min(+Math.floor(S/4294967296),4294967295)|0)>>>0:~~+Math.ceil((S-+(~~S>>>0))/4294967296)>>>0:0)];O[c+80>>2]=T[0];O[c+84>>2]=T[1];return 0}var Xb=void 0;function Yb(){Xb+=4;return O[Xb-4>>2]}function Z(a){a=y.Ta(a);if(!a)throw new y.ErrnoError(8);return a}
function Zb(a,b,c){function e(q){return(q=q.toTimeString().match(/\(([A-Za-z ]+)\)$/))?q[1]:"GMT"}var f=(new Date).getFullYear(),g=new Date(f,0,1),k=new Date(f,6,1);f=g.getTimezoneOffset();var l=k.getTimezoneOffset();O[a>>2]=60*Math.max(f,l);O[b>>2]=Number(f!=l);a=e(g);b=e(k);a=Oa(a);b=Oa(b);l<f?(P[c>>2]=a,P[c+4>>2]=b):(P[c>>2]=b,P[c+4>>2]=a)}function $b(a,b,c){$b.tc||($b.tc=!0,Zb(a,b,c))}var ac;ac=sa?()=>{var a=process.hrtime();return 1E3*a[0]+a[1]/1E6}:()=>performance.now();var bc={};
function cc(){if(!dc){var a={USER:"web_user",LOGNAME:"web_user",PATH:"/",PWD:"/",HOME:"/home/web_user",LANG:("object"==typeof navigator&&navigator.languages&&navigator.languages[0]||"C").replace("-","_")+".UTF-8",_:pa||"./this.program"},b;for(b in bc)void 0===bc[b]?delete a[b]:a[b]=bc[b];var c=[];for(b in a)c.push(b+"="+a[b]);dc=c}return dc}var dc;
function ec(a,b,c,e){a||(a=this);this.parent=a;this.mount=a.mount;this.eb=null;this.id=y.Pc++;this.name=b;this.mode=c;this.node_ops={};this.stream_ops={};this.rdev=e}Object.defineProperties(ec.prototype,{read:{get:function(){return 365===(this.mode&365)},set:function(a){a?this.mode|=365:this.mode&=-366}},write:{get:function(){return 146===(this.mode&146)},set:function(a){a?this.mode|=146:this.mode&=-147}},Kc:{get:function(){return y.isDir(this.mode)}},Cb:{get:function(){return y.jb(this.mode)}}});
y.FSNode=ec;y.ec();var xb;function ca(a,b){var c=Array(d(a)+1);a=r(a,c,0,c.length);b&&(c.length=a);return c}
var gc={a:function(a,b,c,e){N("Assertion failed: "+I(a)+", at: "+[b?I(b):"unknown filename",c,e?I(e):"unknown function"])},g:function(a,b){try{return a=I(a),y.chmod(a,b),0}catch(c){if("undefined"==typeof y||!(c instanceof y.ErrnoError))throw c;return-c.Ja}},I:function(a,b,c){try{b=I(b);b=yb(a,b);if(c&-8)return-28;var e=y.lookupPath(b,{Na:!0}).node;if(!e)return-44;a="";c&4&&(a+="r");c&2&&(a+="w");c&1&&(a+="x");return a&&y.Ua(e,a)?-2:0}catch(f){if("undefined"==typeof y||!(f instanceof y.ErrnoError))throw f;
return-f.Ja}},h:function(a,b){try{return y.fchmod(a,b),0}catch(c){if("undefined"==typeof y||!(c instanceof y.ErrnoError))throw c;return-c.Ja}},H:function(a,b,c){try{return y.fchown(a,b,c),0}catch(e){if("undefined"==typeof y||!(e instanceof y.ErrnoError))throw e;return-e.Ja}},b:function(a,b,c){Xb=c;try{var e=Z(a);switch(b){case 0:var f=Yb();return 0>f?-28:y.Qb(e,f).fd;case 1:case 2:return 0;case 3:return e.flags;case 4:return f=Yb(),e.flags|=f,0;case 5:return f=Yb(),Qa[f+0>>1]=2,0;case 6:case 7:return 0;
case 16:case 8:return-28;case 9:return O[fc()>>2]=28,-1;default:return-28}}catch(g){if("undefined"==typeof y||!(g instanceof y.ErrnoError))throw g;return-g.Ja}},G:function(a,b){try{var c=Z(a);return Wb(y.stat,c.path,b)}catch(e){if("undefined"==typeof y||!(e instanceof y.ErrnoError))throw e;return-e.Ja}},l:function(a,b,c){try{b=c+2097152>>>0<4194305-!!b?(b>>>0)+4294967296*c:NaN;if(isNaN(b))return-61;y.Fc(a,b);return 0}catch(e){if("undefined"==typeof y||!(e instanceof y.ErrnoError))throw e;return-e.Ja}},
B:function(a,b){try{if(0===b)return-28;var c=y.cwd(),e=d(c)+1;if(b<e)return-68;r(c,u,a,b);return e}catch(f){if("undefined"==typeof y||!(f instanceof y.ErrnoError))throw f;return-f.Ja}},E:function(a,b){try{return a=I(a),Wb(y.lstat,a,b)}catch(c){if("undefined"==typeof y||!(c instanceof y.ErrnoError))throw c;return-c.Ja}},y:function(a,b,c){try{return b=I(b),b=yb(a,b),b=W(b),"/"===b[b.length-1]&&(b=b.substr(0,b.length-1)),y.mkdir(b,c,0),0}catch(e){if("undefined"==typeof y||!(e instanceof y.ErrnoError))throw e;
return-e.Ja}},D:function(a,b,c,e){try{b=I(b);var f=e&256;b=yb(a,b,e&4096);return Wb(f?y.lstat:y.stat,b,c)}catch(g){if("undefined"==typeof y||!(g instanceof y.ErrnoError))throw g;return-g.Ja}},v:function(a,b,c,e){Xb=e;try{b=I(b);b=yb(a,b);var f=e?Yb():0;return y.open(b,c,f).fd}catch(g){if("undefined"==typeof y||!(g instanceof y.ErrnoError))throw g;return-g.Ja}},t:function(a,b,c,e){try{b=I(b);b=yb(a,b);if(0>=e)return-28;var f=y.readlink(b),g=Math.min(e,d(f)),k=H[c+g];r(f,u,c,e+1);H[c+g]=k;return g}catch(l){if("undefined"==
typeof y||!(l instanceof y.ErrnoError))throw l;return-l.Ja}},s:function(a){try{return a=I(a),y.rmdir(a),0}catch(b){if("undefined"==typeof y||!(b instanceof y.ErrnoError))throw b;return-b.Ja}},F:function(a,b){try{return a=I(a),Wb(y.stat,a,b)}catch(c){if("undefined"==typeof y||!(c instanceof y.ErrnoError))throw c;return-c.Ja}},p:function(a,b,c){try{return b=I(b),b=yb(a,b),0===c?y.unlink(b):512===c?y.rmdir(b):N("Invalid flags passed to unlinkat"),0}catch(e){if("undefined"==typeof y||!(e instanceof y.ErrnoError))throw e;
return-e.Ja}},n:function(a,b,c){try{b=I(b);b=yb(a,b,!0);if(c){var e=O[c>>2],f=O[c+4>>2];g=1E3*e+f/1E6;c+=8;e=O[c>>2];f=O[c+4>>2];k=1E3*e+f/1E6}else var g=Date.now(),k=g;y.Yc(b,g,k);return 0}catch(l){if("undefined"==typeof y||!(l instanceof y.ErrnoError))throw l;return-l.Ja}},e:function(){return Date.now()},i:function(a,b){a=new Date(1E3*O[a>>2]);O[b>>2]=a.getSeconds();O[b+4>>2]=a.getMinutes();O[b+8>>2]=a.getHours();O[b+12>>2]=a.getDate();O[b+16>>2]=a.getMonth();O[b+20>>2]=a.getFullYear()-1900;O[b+
24>>2]=a.getDay();var c=new Date(a.getFullYear(),0,1);O[b+28>>2]=(a.getTime()-c.getTime())/864E5|0;O[b+36>>2]=-(60*a.getTimezoneOffset());var e=(new Date(a.getFullYear(),6,1)).getTimezoneOffset();c=c.getTimezoneOffset();O[b+32>>2]=(e!=c&&a.getTimezoneOffset()==Math.min(c,e))|0},w:function(a,b,c,e,f,g,k){try{if(0!==a)return-28;var l=y.Ta(f);if(!l)return-8;var q=y.mmap(l,b,g,c,e),m=q.Uc;O[k>>2]=q.lc;return m}catch(p){if("undefined"==typeof y||!(p instanceof y.ErrnoError))throw p;return-p.Ja}},x:function(a,
b,c,e,f,g){try{var k=y.Ta(f);if(k&&c&2){var l=u.slice(a,a+b);y.msync(k,l,g,b,e)}}catch(q){if("undefined"==typeof y||!(q instanceof y.ErrnoError))throw q;return-q.Ja}},j:$b,q:function(){return 2147483648},d:ac,o:function(a,b,c){u.copyWithin(a,b,b+c)},c:function(a){var b=u.length;a>>>=0;if(2147483648<a)return!1;for(var c=1;4>=c;c*=2){var e=b*(1+.2/c);e=Math.min(e,a+100663296);var f=Math;e=Math.max(a,e);f=f.min.call(f,2147483648,e+(65536-e%65536)%65536);a:{try{Ga.grow(f-Pa.byteLength+65535>>>16);Ta();
var g=1;break a}catch(k){}g=void 0}if(g)return!0}return!1},z:function(a,b){var c=0;cc().forEach(function(e,f){var g=b+c;f=P[a+4*f>>2]=g;for(g=0;g<e.length;++g)H[f++>>0]=e.charCodeAt(g);H[f>>0]=0;c+=e.length+1});return 0},A:function(a,b){var c=cc();P[a>>2]=c.length;var e=0;c.forEach(function(f){e+=f.length+1});P[b>>2]=e;return 0},f:function(a){try{var b=Z(a);y.close(b);return 0}catch(c){if("undefined"==typeof y||!(c instanceof y.ErrnoError))throw c;return c.Ja}},m:function(a,b){try{var c=Z(a),e=c.tty?
2:y.isDir(c.mode)?3:y.Za(c.mode)?7:4;H[b>>0]=e;return 0}catch(f){if("undefined"==typeof y||!(f instanceof y.ErrnoError))throw f;return f.Ja}},u:function(a,b,c,e){try{a:{var f=Z(a);a=b;for(var g=b=0;g<c;g++){var k=P[a>>2],l=P[a+4>>2];a+=8;var q=y.read(f,H,k,l,void 0);if(0>q){var m=-1;break a}b+=q;if(q<l)break}m=b}O[e>>2]=m;return 0}catch(p){if("undefined"==typeof y||!(p instanceof y.ErrnoError))throw p;return p.Ja}},k:function(a,b,c,e,f){try{b=c+2097152>>>0<4194305-!!b?(b>>>0)+4294967296*c:NaN;if(isNaN(b))return 61;
var g=Z(a);y.llseek(g,b,e);T=[g.position>>>0,(S=g.position,1<=+Math.abs(S)?0<S?(Math.min(+Math.floor(S/4294967296),4294967295)|0)>>>0:~~+Math.ceil((S-+(~~S>>>0))/4294967296)>>>0:0)];O[f>>2]=T[0];O[f+4>>2]=T[1];g.zb&&0===b&&0===e&&(g.zb=null);return 0}catch(k){if("undefined"==typeof y||!(k instanceof y.ErrnoError))throw k;return k.Ja}},C:function(a){try{var b=Z(a);return b.stream_ops&&b.stream_ops.fsync?-b.stream_ops.fsync(b):0}catch(c){if("undefined"==typeof y||!(c instanceof y.ErrnoError))throw c;
return c.Ja}},r:function(a,b,c,e){try{a:{var f=Z(a);a=b;for(var g=b=0;g<c;g++){var k=P[a>>2],l=P[a+4>>2];a+=8;var q=y.write(f,H,k,l,void 0);if(0>q){var m=-1;break a}b+=q}m=b}P[e>>2]=m;return 0}catch(p){if("undefined"==typeof y||!(p instanceof y.ErrnoError))throw p;return p.Ja}}};
(function(){function a(f){Module.asm=f.exports;Ga=Module.asm.J;Ta();L=Module.asm.Ba;Va.unshift(Module.asm.K);eb()}function b(f){a(f.instance)}function c(f){return ib().then(function(g){return WebAssembly.instantiate(g,e)}).then(function(g){return g}).then(f,function(g){K("failed to asynchronously prepare wasm: "+g);N(g)})}var e={a:gc};ab();if(Module.instantiateWasm)try{return Module.instantiateWasm(e,a)}catch(f){return K("Module.instantiateWasm callback failed with error: "+f),!1}(function(){return Fa||
"function"!=typeof WebAssembly.instantiateStreaming||fb()||R.startsWith("file://")||"function"!=typeof fetch?c(b):fetch(R,{credentials:"same-origin"}).then(function(f){return WebAssembly.instantiateStreaming(f,e).then(b,function(g){K("wasm streaming compile failed: "+g);K("falling back to ArrayBuffer instantiation");return c(b)})})})();return{}})();Module.___wasm_call_ctors=function(){return(Module.___wasm_call_ctors=Module.asm.K).apply(null,arguments)};
Module._sqlite3_vfs_find=function(){return(Module._sqlite3_vfs_find=Module.asm.L).apply(null,arguments)};Module._sqlite3_free=function(){return(Module._sqlite3_free=Module.asm.M).apply(null,arguments)};var fc=Module.___errno_location=function(){return(fc=Module.___errno_location=Module.asm.N).apply(null,arguments)};Module._sqlite3_finalize=function(){return(Module._sqlite3_finalize=Module.asm.O).apply(null,arguments)};
Module._sqlite3_reset=function(){return(Module._sqlite3_reset=Module.asm.P).apply(null,arguments)};Module._sqlite3_clear_bindings=function(){return(Module._sqlite3_clear_bindings=Module.asm.Q).apply(null,arguments)};Module._sqlite3_value_blob=function(){return(Module._sqlite3_value_blob=Module.asm.R).apply(null,arguments)};Module._sqlite3_value_text=function(){return(Module._sqlite3_value_text=Module.asm.S).apply(null,arguments)};
Module._sqlite3_value_bytes=function(){return(Module._sqlite3_value_bytes=Module.asm.T).apply(null,arguments)};Module._sqlite3_value_double=function(){return(Module._sqlite3_value_double=Module.asm.U).apply(null,arguments)};Module._sqlite3_value_int=function(){return(Module._sqlite3_value_int=Module.asm.V).apply(null,arguments)};Module._sqlite3_value_type=function(){return(Module._sqlite3_value_type=Module.asm.W).apply(null,arguments)};
Module._sqlite3_result_blob=function(){return(Module._sqlite3_result_blob=Module.asm.X).apply(null,arguments)};Module._sqlite3_result_double=function(){return(Module._sqlite3_result_double=Module.asm.Y).apply(null,arguments)};Module._sqlite3_result_error=function(){return(Module._sqlite3_result_error=Module.asm.Z).apply(null,arguments)};Module._sqlite3_result_int=function(){return(Module._sqlite3_result_int=Module.asm._).apply(null,arguments)};
Module._sqlite3_result_int64=function(){return(Module._sqlite3_result_int64=Module.asm.$).apply(null,arguments)};Module._sqlite3_result_null=function(){return(Module._sqlite3_result_null=Module.asm.aa).apply(null,arguments)};Module._sqlite3_result_text=function(){return(Module._sqlite3_result_text=Module.asm.ba).apply(null,arguments)};Module._sqlite3_step=function(){return(Module._sqlite3_step=Module.asm.ca).apply(null,arguments)};
Module._sqlite3_column_count=function(){return(Module._sqlite3_column_count=Module.asm.da).apply(null,arguments)};Module._sqlite3_data_count=function(){return(Module._sqlite3_data_count=Module.asm.ea).apply(null,arguments)};Module._sqlite3_column_blob=function(){return(Module._sqlite3_column_blob=Module.asm.fa).apply(null,arguments)};Module._sqlite3_column_bytes=function(){return(Module._sqlite3_column_bytes=Module.asm.ga).apply(null,arguments)};
Module._sqlite3_column_double=function(){return(Module._sqlite3_column_double=Module.asm.ha).apply(null,arguments)};Module._sqlite3_column_text=function(){return(Module._sqlite3_column_text=Module.asm.ia).apply(null,arguments)};Module._sqlite3_column_type=function(){return(Module._sqlite3_column_type=Module.asm.ja).apply(null,arguments)};Module._sqlite3_column_name=function(){return(Module._sqlite3_column_name=Module.asm.ka).apply(null,arguments)};
Module._sqlite3_bind_blob=function(){return(Module._sqlite3_bind_blob=Module.asm.la).apply(null,arguments)};Module._sqlite3_bind_double=function(){return(Module._sqlite3_bind_double=Module.asm.ma).apply(null,arguments)};Module._sqlite3_bind_int=function(){return(Module._sqlite3_bind_int=Module.asm.na).apply(null,arguments)};Module._sqlite3_bind_text=function(){return(Module._sqlite3_bind_text=Module.asm.oa).apply(null,arguments)};
Module._sqlite3_bind_parameter_index=function(){return(Module._sqlite3_bind_parameter_index=Module.asm.pa).apply(null,arguments)};Module._sqlite3_sql=function(){return(Module._sqlite3_sql=Module.asm.qa).apply(null,arguments)};Module._sqlite3_normalized_sql=function(){return(Module._sqlite3_normalized_sql=Module.asm.ra).apply(null,arguments)};Module._sqlite3_errmsg=function(){return(Module._sqlite3_errmsg=Module.asm.sa).apply(null,arguments)};
Module._sqlite3_exec=function(){return(Module._sqlite3_exec=Module.asm.ta).apply(null,arguments)};Module._sqlite3_prepare_v2=function(){return(Module._sqlite3_prepare_v2=Module.asm.ua).apply(null,arguments)};Module._sqlite3_changes=function(){return(Module._sqlite3_changes=Module.asm.va).apply(null,arguments)};Module._sqlite3_close_v2=function(){return(Module._sqlite3_close_v2=Module.asm.wa).apply(null,arguments)};
Module._sqlite3_create_function_v2=function(){return(Module._sqlite3_create_function_v2=Module.asm.xa).apply(null,arguments)};Module._sqlite3_open=function(){return(Module._sqlite3_open=Module.asm.ya).apply(null,arguments)};var ba=Module._malloc=function(){return(ba=Module._malloc=Module.asm.za).apply(null,arguments)},ea=Module._free=function(){return(ea=Module._free=Module.asm.Aa).apply(null,arguments)};
Module._RegisterExtensionFunctions=function(){return(Module._RegisterExtensionFunctions=Module.asm.Ca).apply(null,arguments)};Module._register_for_idb=function(){return(Module._register_for_idb=Module.asm.Da).apply(null,arguments)};
var vb=Module._emscripten_builtin_memalign=function(){return(vb=Module._emscripten_builtin_memalign=Module.asm.Ea).apply(null,arguments)},ia=Module.stackSave=function(){return(ia=Module.stackSave=Module.asm.Fa).apply(null,arguments)},ka=Module.stackRestore=function(){return(ka=Module.stackRestore=Module.asm.Ga).apply(null,arguments)},C=Module.stackAlloc=function(){return(C=Module.stackAlloc=Module.asm.Ha).apply(null,arguments)};
Module.cwrap=function(a,b,c,e){c=c||[];var f=c.every(function(g){return"number"===g});return"string"!==b&&f&&!e?Module["_"+a]:function(){return Ia(a,b,c,arguments)}};Module.UTF8ToString=I;Module.stackSave=ia;Module.stackRestore=ka;Module.stackAlloc=C;Module.FS=y;var hc;$a=function ic(){hc||jc();hc||($a=ic)};
function jc(){function a(){if(!hc&&(hc=!0,Module.calledRun=!0,!Ha)){Module.noFSInit||y.ib.Bb||y.ib();y.bc=!1;jb(Va);if(Module.onRuntimeInitialized)Module.onRuntimeInitialized();if(Module.postRun)for("function"==typeof Module.postRun&&(Module.postRun=[Module.postRun]);Module.postRun.length;){var b=Module.postRun.shift();Wa.unshift(b)}jb(Wa)}}if(!(0<Ya)){if(Module.preRun)for("function"==typeof Module.preRun&&(Module.preRun=[Module.preRun]);Module.preRun.length;)Xa();jb(Ua);0<Ya||(Module.setStatus?(Module.setStatus("Running..."),
setTimeout(function(){setTimeout(function(){Module.setStatus("")},1);a()},1)):a())}}Module.run=jc;if(Module.preInit)for("function"==typeof Module.preInit&&(Module.preInit=[Module.preInit]);0<Module.preInit.length;)Module.preInit.pop()();jc();


        // The shell-pre.js and emcc-generated code goes above
        return Module;
    }); // The end of the promise being returned

  return initSqlJsPromise;
} // The end of our initSqlJs function

// This bit below is copied almost exactly from what you get when you use the MODULARIZE=1 flag with emcc
// However, we don't want to use the emcc modularization. See shell-pre.js
if (typeof exports === 'object' && typeof module === 'object'){
    module.exports = initSqlJs;
    // This will allow the module to be used in ES6 or CommonJS
    module.exports.default = initSqlJs;
}
else if (typeof define === 'function' && define['amd']) {
    define([], function() { return initSqlJs; });
}
else if (typeof exports === 'object'){
    exports["Module"] = initSqlJs;
}
